@@ -12,7 +12,7 @@ Usage::
     session_client: ForecastQueryServiceClient = session.client("forecastquery")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING
+from typing import Any, Dict, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
 
@@ -21,24 +21,24 @@ __all__ = ("ForecastQueryServiceClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    InvalidInputException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    LimitExceededException: Boto3ClientError
-    ResourceInUseException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    InvalidInputException: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    LimitExceededException: Type[Boto3ClientError]
+    ResourceInUseException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class ForecastQueryServiceClient:
     """
-    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/forecastquery.html#ForecastQueryService.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -49,7 +49,7 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         """
 
     def query_forecast(
@@ -61,5 +61,5 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> QueryForecastResponseTypeDef:
         """
-        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         """
